// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
// 'starter.services' is found in services.js
// 'starter.controllers' is found in controllers.js
angular.module('starter', ['ionic', 'starter.controllers', 'starter.services', 'angular-carousel', 'LocalStorageModule', 'angularMoment','pouchdb','timer','ng-sortable'])

.run(function($ionicPlatform, $state, $rootScope, amMoment, DB, Round, User, $ionicPopup, $ionicLoading) {
	$ionicPlatform.ready(function() {
		if (window.cordova && window.cordova.plugins.Keyboard) {
			cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
		}
		if (window.StatusBar) {
			StatusBar.styleDefault();
		}
		if(window.Connection) {
			if(navigator.connection.type == Connection.NONE) {
				$ionicPopup.confirm({
					title: 'No tienes Internet',
					content: 'Necesitas Internet para jugar a La Gran Prueba. Asegúrate de tener una conexión estable.'
				}).then(function(result) {
					if(!result) {
						ionic.Platform.exitApp();
					}
				});
			}
		}
	});
    $rootScope.$state = $state;
    amMoment.changeLocale('es');

	//fondo
	$rootScope.$on('$stateChangeStart', function (event, toState, toParams, fromState, fromParams) {
		console.log('############ fromState.name:', fromState.name);
		console.log('############ toState.name:' , toState.name);
		if(toState.name === 'login'){
			$ionicLoading.show({
				content: 'Loading',
				animation: 'fade-in',
				showBackdrop: true,
				maxWidth: 200,
				showDelay: 0
	    	});
			console.log('login! checking login...');
			User.getUser().then(function(response){
				$state.go('tab.characters.carrusel');
				$ionicLoading.hide();
			}).catch(function(err){
				console.log('login error:', err);
				$ionicLoading.hide();
			});
		}

		//acá debe ir también la lógica de logueo, botarlo si no está logueado y mantenerlo si lo está
	    switch(toState.name) {
	        case 'round.question':
	            $rootScope.fondo = 'bg-question';
	            break;
	        case 'challenge.question':
	            $rootScope.fondo = 'bg-question';
	            break;
	        case 'tab.profile.notifications':
	            $rootScope.fondo = 'bg-profile';
	            break;
	        case 'tab.profile.questions':
	            $rootScope.fondo = 'bg-profile';
	            break;

	        default:
	            $rootScope.fondo = '';
	            break;
	    }

		if(fromState.name == 'round.question' && toState.name != 'round.question'){
			$rootScope.$broadcast('timer-reset');
			Round.initComodines();
		}

	});

    DB.init();

})

.config(function($ionicConfigProvider, $stateProvider, $urlRouterProvider, pouchDBProvider, POUCHDB_DEFAULT_METHODS) {

	$ionicConfigProvider.tabs.position('bottom');
	$ionicConfigProvider.backButton.previousTitleText('Volver');
	$ionicConfigProvider.tabs.style('standard');
	$ionicConfigProvider.navBar.alignTitle('center');

	$stateProvider

	.state('login', {
		url: '/',
		templateUrl: 'templates/login.html',
		controller: 'LoginCtrl'
	})

	.state('register', {
		url: '/register',
		templateUrl: 'templates/register.html',
		controller: 'RegisterCtrl'
	})

	.state('forgot', {
		url: '/forgot',
		templateUrl: 'templates/forgot.html',
		controller: 'ForgotCtrl'
	})

	.state('map', {
		url: '/map/:materia/:elstage/:elround',
		templateUrl: 'templates/map.html',
		controller: 'MapCtrl',
		cache: false
	})

	.state('vs', {
		url: '/vs/:challengeid',
		templateUrl: 'templates/vs.html',
		controller: 'VsCtrl',
		cache: false
	})

	.state('round', {
		url: '/round/:materia/:elstage/:elround',
		templateUrl: 'templates/round.html',
		abstract: true,
		controller: 'RoundCtrl',
		cache: false
	})

	.state('round.question', {
		url: '/:laquestion',
		views: {
			'round-question': {
				templateUrl: 'templates/round-question.html',
				controller: 'QuestionCtrl'
			}
		}
	})

	.state('challenge', {
		url: '/challenge/:challengeid',
		templateUrl: 'templates/round.html',
		abstract: true,
		controller: 'RoundCtrl',
		cache: false
	})

	.state('challenge.question', {
		url: '/:laquestion',
		views: {
			'round-question': {
				templateUrl: 'templates/round-question.html',
				controller: 'QuestionCtrl'
			}
		}
	})

	.state('finished', {
		url: '/finished/:type/:materia/:elstage/:elround',
		templateUrl: 'templates/finished.html',
		controller: 'FinishedCtrl'
	})

	.state('challengeFinished', {
		url: '/challengefinished/:result',
		templateUrl: 'templates/challengefinished.html',
		controller: 'ChallengeFinishedCtrl'
	})

	.state('tab', {
		url: "/tab",
		abstract: true,
		templateUrl: "templates/tabs.html"
	})

	.state('tab.characters', {
		url: '/characters',
		views: {
		'tab-characters': {
			templateUrl: 'templates/tab-characters.html'
			}
		}
	})

	.state('tab.characters.carrusel', {
		url: '/carrusel',
		views: {
			'inception': {
				templateUrl: 'templates/tab-characters-carrusel.html',
				controller: 'CharactersCtrl'
			}
		}
	})

	.state('tab.profile', {
		url: '/profile',
		views: {
			'tab-profile': {
				templateUrl: 'templates/tab-profile.html',
				controller: 'ProfileCtrl'
			}
		}
	})


	.state('tab.edit', {
		url: '/editar',
		views: {
			'tab-profile': {
				templateUrl: 'templates/tab-edit.html',
				controller: 'ProfileEditCtrl'
			}
		}
	})

	.state('tab.profile.notifications', {
		url: '/notifications',
		views: {
			'notification': {
				templateUrl: 'templates/tab-profile-notifications.html',
				controller: 'NotificationsCtrl'
			}
		}
	})

	.state('tab.notification', {
		url: '/notification/:notificationid',
		views: {
			'tab-profile': {
				templateUrl: 'templates/tab-profile-notification.html',
				controller: 'NotificationCtrl'
			}
		}
	})

	.state('tab.challenge', {
		url: '/challenge/:challengeid',
		views: {
			'tab-profile': {
				templateUrl: 'templates/tab-profile-challenge.html',
				controller: 'ChallengeNotificationCtrl'
			}
		}
	})

	.state('tab.profile.achievements', {
		url: '/achievements',
		views: {
			'notification': {
				templateUrl: 'templates/tab-profile-achievements.html',
				controller: 'AchievementsCtrl'
			}
		}
	})

	.state('tab.profile.questions', {
		url: '/questions',
		views: {
			'notification': {
				templateUrl: 'templates/tab-profile-questions.html',
				controller: 'HairyQuestionsCtrl'
			}
		}
	})

	.state('tab.chat-detail', {
		url: '/chats/:chatId',
		views: {
			'tab-chats': {
				templateUrl: 'templates/chat-detail.html',
				controller: 'ChatDetailCtrl'
			}
		}
	})

	.state('tab.ranking', {
		url: '/ranking',
		views: {
			'tab-ranking': {
				templateUrl: 'templates/tab-ranking.html',
				controller: 'RankingCtrl'
			}
		}
	});

	// if none of the above states are matched, use this as the fallback
	$urlRouterProvider.otherwise('/');

	pouchDBProvider.methods = POUCHDB_DEFAULT_METHODS.concat([
		'load',
		'search'
	]);
})
.constant('laconfig', {
    'backend' : 'http://api.multinet.cl/preunab/',
    'version' : 0.1
});