angular.module('starter.services', [])

.factory('DB', function($http, pouchDB, $q, Utils){
	var esto = this;
	esto.user = null;
	esto.questions = null;
	esto.subject = null;

	esto.init = function(){
		console.log('db.init');
		esto.user = pouchDB('user', {adapter: 'websql'});
		esto.questions = pouchDB('questions', {adapter: 'websql'});
		esto.subject = pouchDB('subject', {adapter: 'websql'});
		esto.round = pouchDB('round', {adapter: 'websql'});

 		esto.checkAndLoad(esto.questions, 'data/questions', 11);

		esto.checkAndLoadFromJson(esto.subject, 'data/subjects.json');
		esto.questionsIndex();
/*
 		esto.composeFromJson();
 		esto.questions.replicate.to('http://localhost:5984/questions');
*/
	}

	esto.createDesignDoc = function(name, mapFunction) {
		var ddoc = {
			_id: '_design/' + name,
			views: {
			}
		};
		ddoc.views[name] = { map: mapFunction.toString() };
		return ddoc;
	}

	esto.questionsIndex = function(){
		console.log('---------------------------- QuestionsIndex ------------------------------');

		var ddoc = esto.createDesignDoc('questionid', function(doc){
			emit(doc.id);
		});

		esto.questions.put(ddoc).then(function(res){
			console.log('success index questions', res);
		}).then(function(){
			return esto.questions.query('questionid', {stale: 'update_after'});
			console.log('A$$$$$$$$$$$$$ CÁ$$$$$$$$$$$$$$$$$$$$$$$$')
		}).catch(function (err) {
			if(err.status !== 409){
				throw err;
			}
		});
	}

	esto.loadFromJson = function(ladb, url){
		$http({
			method: 'GET',
			url: url
		})
		.then(function(response){
			if(response.status === 200){
				angular.forEach(response.data, function(item, llave){
	 				console.log('el item', item, llave);
	 				if(llave){
		 				item._id = llave;
		 				ladb.put(item).then(function(result){
							console.log('result:', result);
						}).catch(function(err){
							console.log('error:', err);
						});
	 				} else {
		 				ladb.post(item).then(function(result){
							console.log('result:', result);
						}).catch(function(err){
							console.log('error:', err);
						});
	 				}
				});
			} else {
				console.log('otro status:', response.status, response);
			}
		})
	}

	esto.loadFromDump = function(ladb, url, quantity){
		var dumpFiles = [];
		if(quantity){
			for( i = 0; i < quantity; i++ ){
				dumpFiles.push(url + '_'+Utils.zerofill(i, 8)+'.txt');
			}
		}
		console.log('dumpFiles:', dumpFiles);

		var series = PouchDB.utils.Promise.resolve();

		dumpFiles.forEach(function(dumpFile) {
			series = series.then(function () {
				return ladb.load(dumpFile, { proxy: self.remoteserver, ajax:{cache:true}});
			});
		});
		series.then(function() {
			console.log('result load');
		}).catch(function(err){
			console.log('error load', err);
		});
	}

	esto.checkAndLoad = function(ladb, url, quantity){
		ladb.info().then(function(info){
			if(info.doc_count === 0){
				console.log('DB vacía');
				esto.loadFromDump(ladb, url, quantity);
			} else {
				console.log('DB tenía preguntas, proceda...');
			}
		}).catch(function (err) {
			console.log(err);
		});
	}

	esto.checkAndLoadFromJson = function(ladb, url){
		ladb.info().then(function(info){
			if(info.doc_count === 0){
				console.log('DB vacía');
				esto.loadFromJson(ladb, url);
			} else {
				console.log('DB tenía preguntas, proceda...');
			}
		}).catch(function (err) {
			console.log(err);
		});
	}

	esto.composeFromJson = function(ladb, url){

		$http({
			method: 'GET',
			url: 'data/allQuestions.json'
		})
		.success(function(data){
			angular.forEach(data, function(question){
				question.Question._id = question.Question.category.toLowerCase()+'_'+question.Question.stage+'_'+Utils.zerofill(question.Question.round, 2)+'_'+question.Question.id
				esto.questions.put(question.Question).then(function(result){
					console.log('result:', result);
				}).catch(function(err){
					console.log('error:', err);
				});
			});
		})
	}

	return esto;
})
.factory('User', function(DB, laconfig, $http, $q, localStorageService){
	var esto = this;
	esto.getUser = function(id){
		console.log('Ejecuto GetUser');
		id = id || localStorageService.get('user');
		var deferred = $q.defer();
		DB.user.get(id).then(function(result){
			console.log('El user:', result);
			deferred.resolve(result);
		}).catch(function (err){
			deferred.reject(err);
		});
		return deferred.promise;
	}

	esto.updateUser = function(id){
		id = id || localStorageService.get('user');
		var res = $q.defer();
		$http({
			method: 'POST',
			url: laconfig.backend + 'updateUser.json',
			data : {
				userId : id
			}
		})
		.success(function(data){
			data.Players._id = data.Players.id;
			//guardar en db
			console.log('Actualiza el usuario: actualizando');
			esto.saveUser(data.Players).then(function(){
				console.log('Actualiza el usuario: actualizado correctamente');
			}).catch(function(err){
				console.log('login error:', err);
			}).finally(function(){
				console.log('Actualiza el usuario: termina');
			});
			res.resolve(data.Players);
		})
		.error(function(data){
			console.log('response error:', data);
			res.reject(data);
		})

		return res.promise;
	}

	esto.saveUser = function(userInfo){
		var res = $q.defer();
		//Si existe user, trae el _rev para actualizarlo. Sino, lo guarda
		localStorageService.set('user', userInfo.id);

		DB.user.get(userInfo.id).then(function(result){
			userInfo._rev = result._rev;
			DB.user.put(userInfo).then(function(result){
				console.log('updated user:', result);
				res.resolve(result);
			}).catch(function(err){
				console.log('user error put:', err);
				res.reject(err);
			});
		}).catch(function(err){
			console.log('user get error: ¿quizás no existe? insertar', err);
			if(err.status === 404){
				userInfo._id = userInfo.id;
				DB.user.put(userInfo).then(function(result){
					console.log('created user:', result);
					res.resolve(result);
				}).catch(function(err){
					console.log('user error put:', err);
					res.reject(err);
				});
			}
		});
		return res.promise;
	}
	esto.loginFb = function(){
		var res = $q.defer();
		try{
			facebookConnectPlugin.login( ['email'],
				function(response){
					res.resolve(response);
				},
				function (response) {
					res.reject(response)
				}
			);
		} catch(err){
			res.reject(err);
		}
		return res.promise;
	}

	esto.anonLogin = function(){
		var res = $q.defer();
		$http({
			method: 'POST',
			url: laconfig.backend + 'anonLogin.json'
		})
		.success(function(data){
			res.resolve(data);
		}).catch(function(err){
			res.reject(err);
		});
		return res.promise;
	}

	esto.checkFbPermissions = function(fbid){
		var res = $q.defer();
		try{
			console.log('Pidiendo lista de permisos; fbid: ', fbid);
			facebookConnectPlugin.api(fbid, [],
				function(result){
					res.resolve(result);
					console.log('Resultado de Facebook api', result);
				},
				function(err){
					console.log('Error de Facebook api', err);
					res.reject(err);
				}
			);
		} catch (err){
			res.reject(err);
		}
		return res.promise;
	}


	esto.getUserInfoFb = function(fbid) {
		var res = $q.defer();

		esto.checkFbPermissions(fbid).then(function(response){
			console.log(response);
			res.resolve(response);
		}).catch(function(err){
			console.log(err);
			res.reject(err);
		});
		return res.promise;
	}

	esto.getFriendsPermission = function(fbid){
		var res = $q.defer();
		try{
			facebookConnectPlugin.api(fbid, ['user_friends'],
				function(result){
					res.resolve(result);
					console.log('Resultado de Facebook api', result);
				},
				function(err){
					console.log('Error de Facebook api', err);
					res.reject(err);
				}
			);
		} catch(err){
			res.reject(err);
		}
		return res.promise;
	}

	esto.isConnectedtoFb = function(){
		var res = $q.defer();
		try{
			facebookConnectPlugin.getLoginStatus(
				function(status){
					res.resolve(status);
				}
			);
		} catch(err){
			res.reject(err);
		}
		return res.promise;
	}

	esto.checkAndConnectFb = function(){
		var res = $q.defer();
		esto.isConnectedtoFb().then(function(response){
			if(response.status === 'connected'){
				console.log('Auth response', response);
				esto.getUserInfoFb(response.authResponse.userID).then(function(response){
					res.resolve(response);
				}).catch(function(err){
					res.reject(err);
				});
			} else {
				esto.loginFb().then(function(respuesta){
					esto.getUserInfoFb(respuesta.authResponse.userID).then(function(respuesta){
						res.resolve(respuesta);
					}).catch(function(err){
						res.reject(err);
					});
				}).catch(function(err){
					res.reject(err);
				});
			}
		}).catch(function(err){
			res.reject(err);
		});
		return res.promise;
	}

	esto.getFbFriends = function(){
		var res = $q.defer();
		esto.isConnectedtoFb().then(function(response){
			if(response.status === 'connected'){
				esto.getFriendsPermission(response.authResponse.userID).then(function(response){
					console.log('getFriendsPermission en getFbFriends', response);
					esto.getUserInfoFb().then(function(response){
						res.resolve(response);
					}).catch(function(err){
						res.reject(err);
					})
				}).catch(function(err){
					console.log(err);
					res.reject(err);
				})
			} else {
				esto.loginFb().then(function(response){
					esto.getFriendsPermission(response.authResponse.userID).then(function(response){
						console.log('getFriendsPermission en getFbFriends', response);
						esto.getUserInfoFb().then(function(response){
							res.resolve(response);
						}).catch(function(err){
							res.reject(err);
						})
					}).catch(function(err){
						console.log(err);
						res.reject(err);
					})
				});
			}
		});
	}

	return esto;

})
.factory('Subject', function(DB, laconfig, $http, $q, localStorageService, User){
	var esto = this;

	esto.activeSubjects = function(){
		var lasmaterias = [],
			resultado = $q.defer();

		var actualStage = function(){
			//Cuál es la última stage activa?
			var res = $q.defer();
			$http({
				method: 'GET',
				url: laconfig.backend + 'actualStage.json'
			})
			.success(function(data){
				console.log('Actual Stage', data);
				localStorageService.set('actualStage', data.actual_stage);
				res.resolve(data.actual_stage);
			})
			.error(function(err){
				res.reject(err);
			});
			return res.promise;
		}

		var whichRounds = function(){
			//En qué rondas va el Usuario?
			var res = $q.defer(),
				output = [];

			User.getUser().then(function(eluser){
				angular.forEach(eluser, function(value, key){
					if(key.indexOf('round_') === 0){
						var cleankey = key.replace('round_', '');
						output[cleankey] = value;
					}
				});
				res.resolve(output);
			}).catch(function(err){
				res.reject(err);
			});

			return res.promise;
		}

		var whichStages = function(){
			//En qué stages va el Usuario?
			var res = $q.defer(),
				output = [];

			User.getUser().then(function(eluser){
				angular.forEach(eluser, function(value, key) {
					if(key.indexOf('stage_') === 0){
						var cleankey = key.replace('stage_', '');
						output.push({name : cleankey , stage: value});
					}
				});
				res.resolve(output);
			}).catch(function (err){
				res.reject(err);
			});
			return res.promise;
		}

		$q.all([whichStages(), actualStage(), whichRounds()]).then(function(result){
			var cuales = result[0],
				actual = result[1],
				ronda = result[2];
			angular.forEach(cuales, function(cual){
				console.log('El name', 	cual.name);
				if(cual.stage <= actual){
					cual.round = parseInt(ronda[cual.name]);
					lasmaterias[cual.name] = {};
					lasmaterias[cual.name].round = cual.round;
					lasmaterias[cual.name].stage = cual.stage;
				} else {
					cual.round = parseInt(ronda[cual.name]);
					lasmaterias[cual.name] = {};
					lasmaterias[cual.name].round = cual.round;
					lasmaterias[cual.name].stage = cual.stage;
					if(cual.name == 'chemistry' || cual.name == 'biology' || cual.name == 'physics'){
						lasmaterias[cual.name].blocked = true;
					}
				}
			});
			resultado.resolve(lasmaterias);
		}).catch(function(err){
			resultado.reject(err);
		});
		return resultado.promise;
	}

	return esto;

})
.factory('Question', function(DB, pouchDB, laconfig, $q, $state, User, Round, Utils){
	var esto = this;
	esto.destroyRound = function(){
		var res = $q.defer();
		DB.round.destroy().then(function(response){
			console.log('destroy:', response);
			console.log('reconstruyendo DB.round...');
			DB.round = pouchDB('round', {adapter: 'websql'});
			res.resolve();
		}).catch(function(err){
			res.reject(err);
		});
		return res.promise;
	}

	esto.getQuestionsByArray = function(elarray){
		var res = $q.defer(),
			cueris = [];
		angular.forEach(elarray, function(item, key){
			cueris.push(
				esto.getQuestionById(item).then(function(pregunta){
					console.log('pregunta:', pregunta);
					DB.round.put(pregunta.rows[0].doc).then(function(result){
						console.log('result:', result);
					}).catch(function(err){
						if(err.status != 409){
							console.log('error:', err);
						}
					});
				}).catch(function(err){
					console.log('Error getQuestionById composeChallenge', err);
				})
			);
		});

		$q.all(cueris).then(function(){
			DB.round.info().then(function(lainfo){
				res.resolve(lainfo);
			});
		}).catch(function(err){
			console.log('Errores all cueris', err);
		});

		return res.promise;
	}

	esto.composeChallenge = function(elarray){
		var res = $q.defer();
		esto.destroyRound().then(function(){
			esto.getQuestionsByArray(elarray).then(function(response){
				res.resolve(response);
			}).catch(function(err){
				console.log('error en getQuestionsByArray composeChallenge', err);
			});
		}).catch(function(err){
			res.reject(err);
		});
		return res.promise;
	}

	esto.composeRound = function(materiadata){
		var res = $q.defer();
		esto.destroyRound().then(function(){
			User.updateUser().then(function(){
				User.getUser().then(function(eluser){
					console.log('MapCtrl:', materiadata, 'User:', eluser);
					var lamateria = materiadata._id;

					var querystr = lamateria + '_' + eluser['stage_'+lamateria] + '_' + Utils.zerofill(eluser['round_'+lamateria], 2);
					console.log('el querystr', querystr);
					DB.questions.allDocs({
						startkey: querystr,
						endkey: querystr+'\uffff',
						include_docs: true
					}).then(function(resultado){
						//obtiene las 10
						angular.forEach(resultado.rows, function(item, llave){
							DB.round.put(item.doc).then(function(result){
								console.log('result:', result);
							}).catch(function(err){
								if(err.status != 409){
									console.log('error:', err);
								}
							});
						});
						res.resolve(DB.round.info());
					}).catch(function(err){
						res.reject(err);
					})
				}).catch(function (err){
					res.reject(err);
				});
			}).catch(function(err){
				console.log('HAY UN ERROR ACA JEFE', err);
				res.reject(err);
			});
		}).catch(function(err){
			res.reject(err);
		});
		return res.promise;
	}

	esto.eraseQuestion = function(questionid){
		var res = $q.defer();
		DB.round.get(questionid).then(function(doc){
			return DB.round.remove(doc);
		}).then(function(response){
			res.resolve(response);
		}).catch(function(err){
			res.reject(err);
		});
		return res.promise;
	}

	esto.getRandomQuestion = function(){
		var res = $q.defer();
		DB.round.allDocs({
			include_docs : true,
			limit: 1
		}).then(function(resp){
			console.log('get Random question ', resp)
			res.resolve(resp.rows[0].doc);
		}).catch(function(err){
			console.log('ERROR en getRandomQuestion: ¿estará vacía?', err);
			res.reject(err);
		});
		return res.promise;
	}

	esto.getQuestionById = function(elid){
		var res = $q.defer();
		DB.questions.query('questionid', {
			key: elid,
			include_docs: true
		}).then(function(resp){
			res.resolve(resp);
		}).catch(function(err){
			res.reject(err);
		});
		return res.promise;
	}

	esto.nextQuestion = function(actualid, challengeid){
		Round.getRoundQuestionById(actualid).then(function(lapregunta){
			esto.eraseQuestion(actualid).then(function(response){
				console.log(response);
				esto.getRandomQuestion().then(function(pregunta){
					console.log('La pregunta nextQuestion:',pregunta);
					if(challengeid){
						$state.go('challenge.question', {
							laquestion: pregunta._id,
							challengeid: challengeid
						}).then(function(response){
							console.log('pasó pregunta:', response);
						}).catch(function(err){
							console.log('error en ir a pregunta, ¿quizás no quedan?, probablemente es un array vacío', err);
						});
					} else {
						$state.go('round.question', {
							materia: pregunta.category.toLowerCase(),
							elstage: pregunta.stage,
							elround: pregunta.round,
							laquestion: pregunta._id
						}).then(function(response){
							console.log('pasó pregunta:', response);
						}).catch(function(err){
							console.log('error en ir a pregunta, ¿quizás no quedan?, probablemente es un array vacío', err);
						});
					}
				}).catch(function(err){
					console.log('error en getRandomQuestion ¿quizás no quedan?', err);
					console.log(lapregunta.stage, lapregunta.round, challengeid);
					if(challengeid){
						Round.finishChallenge(challengeid, 'ganador');
					} else {
						Round.victory(false, lapregunta.category.toLowerCase(), lapregunta.stage, lapregunta.round);
					}
				});
			}).catch(function(err){
				console.log('error en getQuestionById que trae la pregunta por id, ¿acaso no existe?',err);
			});
		}).catch(function(err){
			console.log('Error en get Question', err);
		});
	}

	esto.getQuestion = function(questionid){
		var res = $q.defer();
		DB.round.get(questionid).then(function(doc){
			DB.round.info().then(function(info){
				doc.numero = info.doc_count - 9;
				res.resolve(doc);
			})
		}).catch(function(err){
			res.reject(err);
		});
		return res.promise;
	}

	esto.initRound = function(materia){
		var res = $q.defer();
		esto.composeRound(materia).then(function(){
			esto.getRandomQuestion().then(function(question){
				res.resolve(question);
			}).catch(function(err){
				res.reject(err);
			})
		}).catch(function(err){
			res.reject(err);
		});
		return res.promise;
	}

	esto.initChallenge = function(elarray){
		var res = $q.defer();
		esto.composeChallenge(elarray).then(function(){
			esto.getRandomQuestion().then(function(question){
				res.resolve(question);
			}).catch(function(err){
				res.reject(err);
			})
		}).catch(function(err){
			res.reject(err);
		});
		return res.promise;
	}

	return esto;

})
.factory('Round', function(DB, pouchDB, laconfig, $q, $rootScope, $http, $state, User, Utils, localStorageService){
	var esto = this;
	esto.finish = function(reason, wildcards, subject){
		var res = $q.defer();
		User.getUser().then(function(eluser){
			$http({
				method: 'POST',
				url: laconfig.backend + 'thisIsTheEnd.json',
				data: {
					reason: reason || 'defeat',
					wildcards: wildcards || false,
					category: subject,
					userid: eluser.id
				}
			}).then(function(response){
				res.resolve(response)
			}).catch(function(err){
				res.reject(err);
			});

		}).catch(function(err){
			res.reject(err);
		});
		return res.promise;
	}

	esto.victory = function(wildcards, materia, elstage, elround){
		var res = $q.defer();
		var victorytype = 'victory';
		if(elround == 15){
			victorytype = 'finishstage';
		}
		esto.finish('victory', wildcards, materia).then(function(response){
			console.log('response', response);
			elround = response.data.jugador.Players['round_' + materia];
			console.log('SIGUIENTE', elround);
			$state.go('finished', {type: victorytype, materia: materia, elstage: elstage, elround: elround }).then(function(response){
				res.resolve(response);
			}).catch(function(err){
				res.reject(err);
			});
		}).catch(function(err){
			res.reject(err);
		}).finally(function(){
			console.log('Actualiza el usuario: comienza');
			User.updateUser();
		});
		return res.promise;
	}

	esto.finishChallenge = function(challengeid, result){
		var res = $q.defer();
		$http({
			method: 'POST',
			url: laconfig.backend + 'judgingTheChallenge.json',
			data: {
				resultado: result,
				challengeId : challengeid
			}
		}).then(function(response){
			$state.go('challengeFinished', {result: result}).then(function(response){
				res.resolve(response);
			}).catch(function(err){
				res.reject(err);
			});
		}).catch(function(err){
			res.reject(err);
		});
		return res.promise;
	}

	esto.getRoundQuestionById = function(actualid){
		var res = $q.defer();
		DB.round.get(actualid).then(function(resp){
			res.resolve(resp);
		}).catch(function(err){
			res.reject(err);
		});
		return res.promise;
	}

	esto.defeat = function(wildcards, materia, elstage, elround, reason){
		var res = $q.defer();
		esto.finish('defeat', wildcards, materia).then(function(response){
			$state.go('finished', {type: reason || 'defeat', materia: materia, elstage: elstage, elround: elround }).then(function(response){
				res.resolve(response);
			}).catch(function(err){
				res.reject(err);
			});
		}).catch(function(err){
			res.reject(err);
		}).finally(function(algo){
			console.log('Actualiza el usuario: comienza');
			User.updateUser();
		});
		return res.promise;
	}

	esto.comodin = function(subject){
		var res = $q.defer();
		User.getUser().then(function(peasant){
			var field = 'points_' + subject;
			var puntajeMateria = peasant.field;
		}).catch(function(err){
			console.log('SE PUDRIO TODO', err);
		});

		return res.promise;
	}

	esto.initComodines = function(){
		console.log('initComodines');
		localStorageService.set('Comodin.agranda', false);
		localStorageService.set('Comodin.tiempo', false);
		localStorageService.set('Comodin.saltar', false);
		$rootScope.$emit('resetComodines');
	}

	esto.returnComodin = function(tipoComodin){
		var res = $q.defer();
		if(angular.isDefined(tipoComodin)){
			var campo = 'Comodin.' + tipoComodin;
			var comodin = localStorageService.get(campo);
			if(angular.isDefined(comodin)){
				console.log(comodin);
				res.resolve(comodin);
			}else{
				res.reject('undefined');
			}
		}
		return res.promise;
	}

	esto.quemaComodin = function(tipoComodin){
		var res = $q.defer();
		if(angular.isDefined(tipoComodin)){
			var campo = 'Comodin.' + tipoComodin;
			var response = localStorageService.set(campo, true);
			if(response != null){
				res.resolve(response);
			}else{
				res.reject('undefined');
			}
		}
		return res.promise;
	}

	esto.guardaPregunta = function(idPregunta){
		var res = $q.defer();
		User.getUser().then(function(eluser){
			$http({
				method: 'POST',
				url: laconfig.backend + 'storeQuestion.json',
				data: {
					preguntaId: idPregunta,
					userId: eluser.id
				}
			}).then(function(response){
				res.resolve(response)
			}).catch(function(err){
				res.reject(err);
			});
		}).catch(function(err){
			res.reject(err);
		});
		return res.promise;
	}

	return esto;
})

.factory('Challenge', function(DB, laconfig, $http, $q, localStorageService, User){
	var esto = this;

	esto.getChallenge = function(challengeid){
		var res = $q.defer();
		$http({
		    method: 'POST',
			url: laconfig.backend + 'areYouTalkingToMe.json',
		    data : {
		        challengeId : challengeid
		    }
		})
		.success(function(data){
			res.resolve(data);
        })
        .error(function(err){
			res.reject(err);
        })
		return res.promise;
	}

	return esto;
})

.service('Utils', function(){
	var esto = this;

	esto.zerofill = function(number, length){
	    var result = number.toString();
	    var pad = length - result.length;

	    while(pad > 0) {
	    	result = '0' + result;
	    	pad--;
	    }
	    return result;
	}

	esto.llaves = function(input){
	    if(!angular.isObject(input)){
			throw Error("Debe er un objeto!!")
	    }
	    return Object.keys(input);
	}

	return this;
})


.directive('compile', function($compile){
	return function(scope, element, attrs){
		scope.$watch(
			function(scope) {
	            return scope.$eval(attrs.compile);
			},
			function(value) {
	            element.html(value);
				$compile(element.contents())(scope);
			}
		)
	}
})

.directive('opcion', function() {
	return {
		restrict: 'E',
		scope: {
			alternativa: '=',
			escorrecta: '&'
		},
		templateUrl: 'templates/partials/opcion.html',
		link: function($scope, $element){
			$scope.isSelected = false;

			$scope.toggleSelected = function(){
				$scope.alternativa.isSelected = !$scope.alternativa.isSelected;
				var seleccionada = $scope.alternativa.isSelected,
					correcta = $scope.alternativa['is_correct'];
				if(correcta && seleccionada){
					console.log('DING');
					$scope.$emit('saveCorrectas', $scope.alternativa.id);
				} else {
					console.log('DERP');
					$scope.$emit('removeCorrectas', $scope.alternativa.id);
				}
				if(seleccionada){
					$scope.$emit('saveSeleccionadas', $scope.alternativa.id);
				} else {
					$scope.$emit('removeSeleccionadas', $scope.alternativa.id);
				}
			}
		}
	};
})

;